@@ -7,7 +7,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: PartsDrawWidget.h 261 2009-01-22 06:48:10Z satofumi $
 */
 
 #include <QWidget>
@@ -19,8 +19,8 @@ class PartsConfig;
 /*!
   \brief パーツ描画ウィジット
 */
-class PartsDrawWidget : public QWidget {
-
+class PartsDrawWidget : public QWidget
+{
   PartsDrawWidget(const PartsDrawWidget& rhs);
   PartsDrawWidget& operator = (const PartsDrawWidget& rhs);
 
@@ -36,7 +36,7 @@ public:
   /*!
     \brief コンストラクタ
 
-    \param parent [i] 親ウィジット
+    \param[in] parent 親ウィジット
   */
   PartsDrawWidget(QWidget* parent = 0);
   ~PartsDrawWidget(void);
