@@ -4,10 +4,16 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: PartsGeneratorWindow.cpp 263 2009-01-30 14:48:10Z satofumi $
 
   \todo コンポーネントの変更を、PartsConfig に反映させる
 */
+
+#include "PartsGeneratorWindow.h"
+#include "PartsDrawWidget.h"
+#include "GenerateConfigHandler.h"
+#include "PartsConfig.h"
+#include "ConvertStdStringPath.h"
 #include <QSettings>
 #include <QCloseEvent>
 #include <QMessageBox>
@@ -17,17 +23,13 @@
 #include <QColorDialog>
 #include <QFileDialog>
 #include <QFileInfo>
-#include "PartsGeneratorWindow.h"
-#include "PartsDrawWidget.h"
-#include "GenerateConfigHandler.h"
-#include "PartsConfig.h"
-#include "ConvertStdStringPath.h"
 
 using namespace qrk;
+using namespace std;
 
 
-struct PartsGeneratorWindow::pImpl {
-
+struct PartsGeneratorWindow::pImpl
+{
   QAction* new_act_;
   QAction* open_act_;
   QAction* save_act_;
@@ -35,12 +37,12 @@ struct PartsGeneratorWindow::pImpl {
   QButtonGroup* button_group_;
   QComboBox* font_combobox_;
   GenerateConfigHandler parts_configs_;
-  std::string work_file_;
+  string work_file_;
   QString first_title_;
 
   pImpl(const QString& config_file, PartsGeneratorWindow* parent)
-    : parts_draw_(NULL) {
-
+    : parts_draw_(NULL)
+  {
     if (config_file.isEmpty()) {
       // デフォルト設定で初期化
       initializeConfig(parent);
@@ -55,8 +57,8 @@ struct PartsGeneratorWindow::pImpl {
   }
 
 
-  void initializeForm(PartsGeneratorWindow* parent) {
-
+  void initializeForm(PartsGeneratorWindow* parent)
+  {
     // Window Title の取得
     first_title_ = parent->windowTitle();
 
@@ -131,8 +133,8 @@ struct PartsGeneratorWindow::pImpl {
 
 
   // 設定をフォームに反映
-  void loadPartsConfig(const PartsConfig& parts, PartsGeneratorWindow* parent) {
-
+  void loadPartsConfig(const PartsConfig& parts, PartsGeneratorWindow* parent)
+  {
     parent->output_label_->setText((parts.type + ".png").c_str());
 
     // !!! フォントを変更する
@@ -143,8 +145,8 @@ struct PartsGeneratorWindow::pImpl {
   }
 
 
-  void updateColorButton(QToolButton* button, const std::string& color_str) {
-
+  void updateColorButton(QToolButton* button, const string& color_str)
+  {
     QColor fore_color = PartsConfig::encodeColor(color_str);
     QPixmap fore_pixmap(32, 32);
     fore_pixmap.fill(fore_color);
@@ -153,15 +155,15 @@ struct PartsGeneratorWindow::pImpl {
 
 
   // プレビュー画像の描画
-  void drawPreviewPixmap(const PartsConfig& parts) {
-
+  void drawPreviewPixmap(const PartsConfig& parts)
+  {
     parts_draw_->updatePreview(parts);
   }
 
 
   // フォントツリーの作成
-  void initializeFontTree(PartsGeneratorWindow* parent) {
-
+  void initializeFontTree(PartsGeneratorWindow* parent)
+  {
     QFontDatabase database;
     foreach (QString family, database.families()) {
       const QStringList styles = database.styles(family);
@@ -185,24 +187,24 @@ struct PartsGeneratorWindow::pImpl {
 
 
   // 設定の読み出し
-  void readSettings(PartsGeneratorWindow* parent) {
-
+  void readSettings(PartsGeneratorWindow* parent)
+  {
     QSettings settings("Hyakuren Soft LTD.", "parts_generator");
     parent->restoreGeometry(settings.value("geometry").toByteArray());
   }
 
 
   // 設定の保存
-  void writeSettings(PartsGeneratorWindow* parent) {
-
+  void writeSettings(PartsGeneratorWindow* parent)
+  {
     QSettings settings("Hyakuren Soft LTD.", "parts_generator");
     settings.setValue("geometry", parent->saveGeometry());
   }
 
 
   // デフォルト設定で初期化
-  void initializeConfig(PartsGeneratorWindow* parent) {
-
+  void initializeConfig(PartsGeneratorWindow* parent)
+  {
     parts_configs_.initialize();
     work_file_ = "";
     setTitle("", parent);
@@ -210,8 +212,8 @@ struct PartsGeneratorWindow::pImpl {
 
 
   // 設定ファイルの読み込み
-  bool loadConfigFile(const char* file, PartsGeneratorWindow* parent) {
-
+  bool loadConfigFile(const char* file, PartsGeneratorWindow* parent)
+  {
     bool ret = parts_configs_.load(file);
     if (ret) {
       // タイトルの更新
@@ -222,27 +224,27 @@ struct PartsGeneratorWindow::pImpl {
   }
 
 
-  PartsConfig& getCurrentPartsConfig(void) {
-
+  PartsConfig& getCurrentPartsConfig(void)
+  {
     int index = button_group_->checkedId();
     return parts_configs_.getPartsConfig(index);
   }
 
 
-  void setSaveEnabled(bool enable) {
-
+  void setSaveEnabled(bool enable)
+  {
     save_act_->setEnabled(enable);
   }
 
 
-  bool getCurrentSaveEnable() {
-
+  bool getCurrentSaveEnable()
+  {
     return save_act_->isEnabled();
   }
 
 
-  void setTitle(const QString& title, PartsGeneratorWindow* parent) {
-
+  void setTitle(const QString& title, PartsGeneratorWindow* parent)
+  {
     if (! title.isEmpty()) {
       parent->setWindowTitle(first_title_ + " -- " + title);
     } else {
@@ -253,7 +255,8 @@ struct PartsGeneratorWindow::pImpl {
 
 
 PartsGeneratorWindow::PartsGeneratorWindow(const QString& config_file)
-  : QMainWindow(), pimpl(new pImpl(config_file, this)) {
+  : QMainWindow(), pimpl(new pImpl(config_file, this))
+{
   setupUi(this);
   pimpl->readSettings(this);
 
@@ -288,36 +291,37 @@ PartsGeneratorWindow::PartsGeneratorWindow(const QString& config_file)
 }
 
 
-PartsGeneratorWindow::~PartsGeneratorWindow(void) {
+PartsGeneratorWindow::~PartsGeneratorWindow(void)
+{
   pimpl->writeSettings(this);
 }
 
 
 // 終了
-void PartsGeneratorWindow::closeEvent(QCloseEvent* event) {
-
+void PartsGeneratorWindow::closeEvent(QCloseEvent* event)
+{
   event->accept();
 }
 
 
 // 新規作成
-void PartsGeneratorWindow::newFile(void) {
-
+void PartsGeneratorWindow::newFile(void)
+{
   pimpl->initializeConfig(this);
   update();
 }
 
 
 // 読み出し
-void PartsGeneratorWindow::openFile(void) {
-
+void PartsGeneratorWindow::openFile(void)
+{
   QString fileName =
     QFileDialog::getOpenFileName(this, tr("Open parts config file."),
 				 toQtStringPath(pimpl->work_file_.c_str()),
                                  tr("config file (*.txt)"));
 
   if (! fileName.isEmpty()) {
-    std::string std_path = toStdStringPath(fileName);
+    string std_path = toStdStringPath(fileName);
     if (pimpl->loadConfigFile(std_path.c_str(), this)) {
       update();
     }
@@ -326,8 +330,8 @@ void PartsGeneratorWindow::openFile(void) {
 
 
 // 保存
-void PartsGeneratorWindow::saveFile(void) {
-
+void PartsGeneratorWindow::saveFile(void)
+{
   if (! pimpl->parts_configs_.save()) {
     // 保存できなければ、ファイル名の入力を促した上で保存する
     saveAsFile();
@@ -337,8 +341,8 @@ void PartsGeneratorWindow::saveFile(void) {
 }
 
 
-bool PartsGeneratorWindow::saveAsFile(void) {
-
+bool PartsGeneratorWindow::saveAsFile(void)
+{
   fprintf(stderr, "saveAsFile()\n");
 
   // ファイル名の入力を促し、保存を試みる
@@ -349,7 +353,7 @@ bool PartsGeneratorWindow::saveAsFile(void) {
 
   if (! fileName.isEmpty()) {
     // 日本語のパスを含む場合への対処
-    std::string std_path = toStdStringPath(fileName);
+    string std_path = toStdStringPath(fileName);
     if (pimpl->parts_configs_.saveAs(std_path.c_str())) {
       pimpl->setSaveEnabled(false);
       QFileInfo fi(std_path.c_str());
@@ -363,8 +367,8 @@ bool PartsGeneratorWindow::saveAsFile(void) {
 
 
 // このアプリケーションについて
-void PartsGeneratorWindow::aboutApplication(void) {
-
+void PartsGeneratorWindow::aboutApplication(void)
+{
   QMessageBox::about(this, tr("About parts_generator"),
                      tr("<h2>Parts generator</h2>"
                         "<p>Theme making sub tool for Qtmclock.</p>"
@@ -374,8 +378,8 @@ void PartsGeneratorWindow::aboutApplication(void) {
 
 
 // フォーム設定とプレビュー画像の更新
-void PartsGeneratorWindow::update(void) {
-
+void PartsGeneratorWindow::update(void)
+{
   int index = pimpl->button_group_->checkedId();
   if (index >= static_cast<int>(pimpl->parts_configs_.size())) {
     return;
@@ -390,8 +394,8 @@ void PartsGeneratorWindow::update(void) {
 
 
 // 画像ファイルの出力
-void PartsGeneratorWindow::outputPixmap(void) {
-
+void PartsGeneratorWindow::outputPixmap(void)
+{
   QFileInfo fi(pimpl->work_file_.c_str());
   QString output_file =
     fi.absoluteDir().absolutePath() + "/" + output_label_->text();
@@ -401,8 +405,8 @@ void PartsGeneratorWindow::outputPixmap(void) {
 
 
 // フォントサイズの変更
-void PartsGeneratorWindow::fontSizeChangedHandler(int value) {
-
+void PartsGeneratorWindow::fontSizeChangedHandler(int value)
+{
   PartsConfig& parts = pimpl->getCurrentPartsConfig();
   parts.font_size = value;
 
@@ -411,8 +415,8 @@ void PartsGeneratorWindow::fontSizeChangedHandler(int value) {
 }
 
 
-void PartsGeneratorWindow::offsetChangedHandler(int value) {
-
+void PartsGeneratorWindow::offsetChangedHandler(int value)
+{
   PartsConfig& parts = pimpl->getCurrentPartsConfig();
   parts.offset = value;
 
@@ -421,8 +425,8 @@ void PartsGeneratorWindow::offsetChangedHandler(int value) {
 }
 
 
-void PartsGeneratorWindow::fontColorClickedHandler(void) {
-
+void PartsGeneratorWindow::fontColorClickedHandler(void)
+{
   PartsConfig& parts = pimpl->getCurrentPartsConfig();
   QColor fore_color = PartsConfig::encodeColor(parts.fore_color);
   QColor color = QColorDialog::getColor(fore_color, this);
@@ -440,8 +444,8 @@ void PartsGeneratorWindow::fontColorClickedHandler(void) {
 }
 
 
-void PartsGeneratorWindow::backgroundColorClickedHandler(void) {
-
+void PartsGeneratorWindow::backgroundColorClickedHandler(void)
+{
   // !!! このあたりは、上と同じ。くくるべき
   PartsConfig& parts = pimpl->getCurrentPartsConfig();
   QColor back_color = PartsConfig::encodeColor(parts.back_color);
@@ -461,16 +465,16 @@ void PartsGeneratorWindow::backgroundColorClickedHandler(void) {
 
 
 // フォントの変更
-void PartsGeneratorWindow::fontChangedHandler(void) {
-
+void PartsGeneratorWindow::fontChangedHandler(void)
+{
   QTreeWidgetItem* item = font_tree_->currentItem();
   QTreeWidgetItem* parent = item->parent();
 
   // 選択されたフォント名、スタイル名の取得
   int column = font_tree_->currentColumn();
-  std::string font_name =
+  string font_name =
     ((parent) ? parent->text(column) : item->text(column)).toStdString();
-  std::string style_name = (parent) ? item->text(column).toStdString() : "";
+  string style_name = (parent) ? item->text(column).toStdString() : "";
 
   PartsConfig& parts = pimpl->getCurrentPartsConfig();
   parts.font_name = font_name;
