@@ -7,17 +7,19 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: PartsGeneratorWindow.h 262 2009-01-30 13:25:37Z satofumi $
 */
 
 #include "ui_PartsGeneratorWindowForm.h"
+#include <memory>
 
 
 /*!
   \brief デジタル部品画像の生成用
 */
 class PartsGeneratorWindow
-  : public QMainWindow, private Ui::PartsGeneratorWindowForm {
+  : public QMainWindow, private Ui::PartsGeneratorWindowForm
+{
   Q_OBJECT;
 
   PartsGeneratorWindow(void);
