@@ -7,31 +7,24 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: SettingConfig.h 276 2009-10-22 03:44:32Z satofumi $
 */
 
-#include <memory>
 #include <QMap>
 #include <QString>
+#include <memory>
 
 
 /*!
   \brief XML 設定ファイルの管理クラス
 */
-class SettingConfig {
-
-  SettingConfig(void);
-  SettingConfig(const SettingConfig& rhs);
-  SettingConfig& operator = (const SettingConfig& rhs);
-
-  struct pImpl;
-  std::auto_ptr<pImpl> pimpl;
-
+class SettingConfig
+{
 public:
   /*!
     \brief コンストラクタ
 
-    \param config_file [i] 設定の XML ファイル
+    \param[in] config_file 設定の XML ファイル
   */
   explicit SettingConfig(const std::string& config_file);
 
@@ -39,8 +32,8 @@ public:
   /*!
     \brief コンストラクタ
 
-    \param tags [o] タグ情報の格納先
-    \param data [i] XML データ配列
+    \param[out] tags タグ情報の格納先
+    \param[in] data XML データ配列
   */
   explicit SettingConfig(QMap<std::string, std::string>& tags,
                          QByteArray& data);
@@ -50,7 +43,7 @@ public:
   /*!
     \brief 値の取得
 
-    \param tag [i] タグ
+    \param[in] tag タグ
 
     \retval 値
   */
@@ -60,8 +53,8 @@ public:
   /*!
     \brief 値の設定
 
-    \param tag [i] タグ
-    \param value [i] 値
+    \param[in] tag タグ
+    \param[in] value 値
   */
   void setValue(const std::string& tag, const std::string& value);
 
@@ -73,6 +66,14 @@ public:
     \retval false エラー
   */
   void save(void);
+
+private:
+  SettingConfig(void);
+  SettingConfig(const SettingConfig& rhs);
+  SettingConfig& operator = (const SettingConfig& rhs);
+
+  struct pImpl;
+  std::auto_ptr<pImpl> pimpl;
 };
 
 #endif /* !SETTING_CONFIG_H */
