@@ -4,20 +4,13 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ThemeClockDraw.cpp 270 2009-09-07 15:27:15Z satofumi $
 
   \todo エラーメッセージの処理
   \todo 時刻毎のベース画像切替え機能を実装する
   \todo アニメーションの設定変更を反映させる
 */
 
-#include <QLabel>
-#include <QVBoxLayout>
-#include <QRegion>
-#include <QBitmap>
-#include <QCloseEvent>
-#include <QPainter>
-#include <QTimer>
 #include "ThemeClockDraw.h"
 #include "RrdaEncoder.h"
 #include "RrdaResource.h"
@@ -25,20 +18,31 @@
 #include "ThemeResource.h"
 #include "AnimationPattern.h"
 #include "AnimationManager.h"
-#include "SplitString.h"
+#include "split.h"
+#include <QLabel>
+#include <QVBoxLayout>
+#include <QRegion>
+#include <QBitmap>
+#include <QCloseEvent>
+#include <QPainter>
+#include <QTimer>
+#include <algorithm>
 
 #ifdef _MSC_VER
 #define snprintf _snprintf
 #endif
 
-
-namespace {
-  typedef QMap<std::string, std::string> TagsMap;
-};
+using namespace std;
 
 
-struct ThemeClockDraw::pImpl {
+namespace
+{
+  typedef QMap<string, string> TagsMap;
+}
 
+
+struct ThemeClockDraw::pImpl
+{
   enum {
     AnimationCycleMsec = 100,
   };
@@ -64,14 +68,14 @@ struct ThemeClockDraw::pImpl {
   AnimationManager* animation_manager_;
   size_t cell_max_;
   size_t pattern_max_;
-  std::vector<AnimationPattern> patterns_;
+  vector<AnimationPattern> patterns_;
   QTimer animation_cycle_timer_;
 
   pImpl(ThemeClockDraw* parent)
     : message_label_(NULL), theme_loaded_(false), parent_widget_(NULL),
       scaling_percent_(100), no_animation_(false), sec_offset_(0),
-      animation_manager_(NULL), cell_max_(0), pattern_max_(0) {
-
+      animation_manager_(NULL), cell_max_(0), pattern_max_(0)
+  {
     // テーマファイルのドラッグを促すフォームを作成
     message_label_ =
       new QLabel(QLabel::tr("Drop theme file in this form."), parent);
@@ -89,18 +93,19 @@ struct ThemeClockDraw::pImpl {
   }
 
 
-  ~pImpl(void) {
+  ~pImpl(void)
+  {
     delete animation_manager_;
   }
 
 
   // テーマファイルの読み出し
-  bool loadThemeFile(const QString& theme_file, const char* key) {
-
+  bool loadThemeFile(const QString& theme_file, const char* key)
+  {
     // リソースの読み出しを行う
     RrdaEncoder rrda_encoder(theme_file.toStdString().c_str(), key);
 
-    std::vector<std::string> resource_files;
+    vector<string> resource_files;
     rrda_encoder.getResourceNames(resource_files);
 
     // "config" がリソースに含まれているかの確認
@@ -113,7 +118,7 @@ struct ThemeClockDraw::pImpl {
     }
 
     // config を読み出してパース
-    std::auto_ptr<RrdaResource> config(rrda_encoder.getResource("config"));
+    auto_ptr<RrdaResource> config(rrda_encoder.getResource("config"));
     size_t size = 0;
     char* p = reinterpret_cast<char*>(config->get(&size));
 
@@ -135,12 +140,12 @@ struct ThemeClockDraw::pImpl {
 
 
   // テーマファイルの追加調整
-  void themeAdditionalAdjust(const std::string& file) {
-
+  void themeAdditionalAdjust(const string& file)
+  {
     // 下位互換性用
     size_t n = file.size();
     if (n >= 20) {
-      std::string last_name = file.substr(n - 20, std::string::npos);
+      string last_name = file.substr(n - 20, string::npos);
       if (! last_name.compare("lm_clocktheme_02.dat")) {
         // Rex ちゃん
         theme_resource_.option["digital/blink"] = "on";
@@ -156,18 +161,16 @@ struct ThemeClockDraw::pImpl {
 
   // リソース名が存在するかを返す
   bool isExist(const char* resource_name,
-               const std::vector<std::string>& resources) {
-
-    std::vector<std::string>::const_iterator p =
-      std::find(resources.begin(), resources.end(), resource_name);
-
-    return (p == resources.end()) ? false : true;
+               const vector<string>& resources)
+  {
+    return (std::find(resources.begin(), resources.end(),
+                      resource_name) != resources.end());
   }
 
 
   // リソースの読み出し
-  bool loadResources(char* p, size_t size, RrdaEncoder& rrda_encoder) {
-
+  bool loadResources(char* p, size_t size, RrdaEncoder& rrda_encoder)
+  {
     // 設定ファイルの読み出し
     QByteArray data(p, size);
     TagsMap tags;
@@ -198,6 +201,7 @@ struct ThemeClockDraw::pImpl {
     loadOption(resource, "digital/sec", tags);
     loadOption(resource, "digital/ampm", tags);
     loadOption(resource, "calendar/month", tags);
+    loadOption(resource, "calendar/zero", tags);
     loadOption(resource, "digital/above", tags);
 
     // デジタル文字を、文字毎に格納
@@ -217,25 +221,25 @@ struct ThemeClockDraw::pImpl {
     // アニメーション情報の読み出し
     loadAnimations(resource, tags, rrda_encoder);
 
-    std::swap(theme_resource_, resource);
+    swap(theme_resource_, resource);
 
     return true;
   }
 
 
   // 画像の読み出し
-  bool loadPixmap(ThemeResource& resource, const std::string& tag_name,
-                  const TagsMap& tags, RrdaEncoder& rrda_encoder) {
-
+  bool loadPixmap(ThemeResource& resource, const string& tag_name,
+                  const TagsMap& tags, RrdaEncoder& rrda_encoder)
+  {
     // タグ名の RRDA リソースからの取得
-    std::string pixmap_tag_name = tags.value(tag_name, "");
+    string pixmap_tag_name = tags.value(tag_name, "");
     if (pixmap_tag_name.empty()) {
       // !!! 存在しない
       return false;
     }
 
     // 画像の読み出し
-    std::auto_ptr<RrdaResource>
+    auto_ptr<RrdaResource>
       config(rrda_encoder.getResource(pixmap_tag_name.c_str()));
     size_t size = 0;
     char* p = reinterpret_cast<char*>(config->get(&size));
@@ -254,10 +258,10 @@ struct ThemeClockDraw::pImpl {
 
 
   // 対応する画像が既に resouce に登録されていなければならない
-  void loadOffset(ThemeResource& resource, const std::string& tag_name,
-                  const std::string& x_tag, const std::string& y_tag,
-                  const TagsMap& tags) {
-
+  void loadOffset(ThemeResource& resource, const string& tag_name,
+                  const string& x_tag, const string& y_tag,
+                  const TagsMap& tags)
+  {
     // 位置の取得と登録
     int x = atoi(tags.value(x_tag, "0").c_str());
     int y = atoi(tags.value(y_tag, "0").c_str());
@@ -272,11 +276,11 @@ struct ThemeClockDraw::pImpl {
 
 
   // オプションの読み出し
-  void loadOption(ThemeResource& resource, const std::string& tag_name,
-                  const TagsMap& tags) {
-
+  void loadOption(ThemeResource& resource, const string& tag_name,
+                  const TagsMap& tags)
+  {
     // オプションの取得と登録
-    std::string tag_value = tags.value(tag_name, "");
+    string tag_value = tags.value(tag_name, "");
     if (tag_value.empty()) {
       // !!! 存在しない
       return;
@@ -287,8 +291,8 @@ struct ThemeClockDraw::pImpl {
 
   // デジタル画像の読み出し
   void loadDigitalCharacter(ThemeResource& resource, TagsMap& tags,
-                            RrdaEncoder& rrda_encoder) {
-
+                            RrdaEncoder& rrda_encoder)
+  {
     // 文字毎に等間隔で分割して登録する
     const char* tag_names[] = {
       "0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
@@ -303,8 +307,8 @@ struct ThemeClockDraw::pImpl {
 
   // カレンダー用画像の読み出し
   bool loadCalendarCharacter(ThemeResource& resource, TagsMap& tags,
-                             RrdaEncoder& rrda_encoder) {
-
+                             RrdaEncoder& rrda_encoder)
+  {
     // 数値文字の読み出し
     const char* number_names[] = {
       "C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", "C8", "C9",
@@ -326,13 +330,14 @@ struct ThemeClockDraw::pImpl {
                               week_pixmap_, "calendar/week", week_names, n)) {
       return false;
     }
+    return true;
   }
 
 
   // セパレータ用画像の読み出し
   bool loadSeparatorCharacter(ThemeResource& resource, TagsMap& tags,
-                              RrdaEncoder& rrda_encoder) {
-
+                              RrdaEncoder& rrda_encoder)
+  {
     // 区切り文字の読み出し
     const char* separator_names[] = {
       "MONTH", "DAY",
@@ -353,8 +358,8 @@ struct ThemeClockDraw::pImpl {
                            RrdaEncoder& rrda_encoder,
                            QVector<QPixmap>& pixmaps,
                            const char* image_tag,
-                           const char* tag_names[], size_t tag_names_size) {
-
+                           const char* tag_names[], size_t tag_names_size)
+  {
     ThemeResource digital_resource;
     if (! loadPixmap(digital_resource, image_tag, tags, rrda_encoder)) {
       return false;
@@ -389,8 +394,8 @@ struct ThemeClockDraw::pImpl {
 
   // アニメーション情報の読み出し
   void loadAnimations(ThemeResource& resource, TagsMap& tags,
-                      RrdaEncoder& rrda_encoder) {
-
+                      RrdaEncoder& rrda_encoder)
+  {
     // !!! 内部実装を、適当に関数化すること
 
     // !!! どこかで、どうにかしてくくる
@@ -429,7 +434,7 @@ struct ThemeClockDraw::pImpl {
       animation.probability = atof(tags[tag_names.probability_tag].c_str());
       animation.cycle_msec = atoi(tags[tag_names.cycle_tag].c_str());
 
-      std::vector<std::string> tokens;
+      vector<string> tokens;
       size_t n = qrk::split(tokens, tags[tag_names.pattern_tag], ", \t");
       for (size_t j = 0; j < n; ++j) {
         animation.cells.push_back(atoi(tokens[j].c_str()));
@@ -442,15 +447,15 @@ struct ThemeClockDraw::pImpl {
 
 
   // フォームの初期化
-  void initializeWidget(ThemeClockDraw* parent) {
-
+  void initializeWidget(ThemeClockDraw* parent)
+  {
     resizeWidget(parent);
   }
 
 
   // リサイズ
-  void resizeWidget(ThemeClockDraw* parent) {
-
+  void resizeWidget(ThemeClockDraw* parent)
+  {
     QPixmap* base_pixmap = theme_resource_.pixmap.value("base/base_org");
     QSize size = base_pixmap->size();
     QSize scaled_size =
@@ -462,20 +467,20 @@ struct ThemeClockDraw::pImpl {
 
 
   // 再描画
-  void paintEvent(ThemeClockDraw* parent) {
-
+  void paintEvent(ThemeClockDraw* parent)
+  {
     QPainter painter(parent);
     ClockPartsDraw::drawPixmaps(painter, true);
   }
 
 
   // テーマのリソースからの読み出し
-  bool loadThemeResouce(const QMap<std::string, QPixmap*>& pixmaps,
-                        const QMap<std::string, QRect>& offset,
+  bool loadThemeResouce(const QMap<string, QPixmap*>& pixmaps,
+                        const QMap<string, QRect>& offset,
                         const QVector<QPoint>& digital_positions,
                         const QVector<QPoint>& calendar_positions,
-                        const TagsMap& option) {
-
+                        const TagsMap& option)
+  {
     // 画像リソースの更新
     theme_resource_.pixmap = pixmaps;
 
@@ -499,18 +504,20 @@ struct ThemeClockDraw::pImpl {
 
 
 ThemeClockDraw::ThemeClockDraw(QWidget* parent)
-  : QWidget(parent), pimpl(new pImpl(this)) {
+  : QWidget(parent), pimpl(new pImpl(this))
+{
 }
 
 
-ThemeClockDraw::~ThemeClockDraw(void) {
+ThemeClockDraw::~ThemeClockDraw(void)
+{
 }
 
 
 // テーマファイルの読み出し
 bool ThemeClockDraw::loadThemeFile(const QString& theme_file,
-                                   const char* key) {
-
+                                   const char* key)
+{
   if (! pimpl->loadThemeFile(theme_file, key)) {
     return false;
   }
@@ -538,15 +545,15 @@ bool ThemeClockDraw::loadThemeFile(const QString& theme_file,
 
 
 // テーマのリソースからの読み出し
-bool ThemeClockDraw::loadThemeResource(const QMap<std::string, QPixmap*>&
+bool ThemeClockDraw::loadThemeResource(const QMap<string, QPixmap*>&
                                        pixmaps,
-                                       const QMap<std::string, QRect>& offset,
+                                       const QMap<string, QRect>& offset,
                                        const QVector<QPoint>&
                                        digital_positions,
                                        const QVector<QPoint>&
                                        calendar_positions,
-                                       const TagsMap& option) {
-
+                                       const TagsMap& option)
+{
   if (! pimpl->loadThemeResouce(pixmaps, offset,
                                 digital_positions, calendar_positions,
                                 option)) {
@@ -561,15 +568,15 @@ bool ThemeClockDraw::loadThemeResource(const QMap<std::string, QPixmap*>&
 
 
 // テーマファイル名の取得
-const QString ThemeClockDraw::getThemeFile(void) {
-
+const QString ThemeClockDraw::getThemeFile(void)
+{
   return pimpl->theme_file_;
 }
 
 
 // 再描画
-void ThemeClockDraw::redraw(int sec_offset, QWidget* parent, int cell_index) {
-
+void ThemeClockDraw::redraw(int sec_offset, QWidget* parent, int cell_index)
+{
   pimpl->sec_offset_ = sec_offset;
   pimpl->parent_widget_ = parent;
   if (pimpl->theme_loaded_) {
@@ -596,7 +603,8 @@ void ThemeClockDraw::redraw(int sec_offset, QWidget* parent, int cell_index) {
 
 
 // 描画イベント
-void ThemeClockDraw::paintEvent(QPaintEvent* event) {
+void ThemeClockDraw::paintEvent(QPaintEvent* event)
+{
   static_cast<void>(event);
 
   if (pimpl->theme_loaded_) {
@@ -606,23 +614,23 @@ void ThemeClockDraw::paintEvent(QPaintEvent* event) {
 
 
 // クローズイベント
-void ThemeClockDraw::closeEvent(QCloseEvent* event) {
-
+void ThemeClockDraw::closeEvent(QCloseEvent* event)
+{
   event->accept();
   emit previewClose();
 }
 
 
 // 描画の拡大率を設定
-void ThemeClockDraw::updateScalingPercent(size_t percent) {
-
+void ThemeClockDraw::updateScalingPercent(size_t percent)
+{
   pimpl->scaling_percent_ = percent;
   pimpl->resizeWidget(this);
 }
 
 
-void ThemeClockDraw::setAnimationOn(bool on) {
-
+void ThemeClockDraw::setAnimationOn(bool on)
+{
   pimpl->no_animation_ = ! on;
 
   // 現在のアニメーション設定を更新する
@@ -631,8 +639,8 @@ void ThemeClockDraw::setAnimationOn(bool on) {
 
 
 // アニメーション開始の評価
-void ThemeClockDraw::evaluateAnimation(void) {
-
+void ThemeClockDraw::evaluateAnimation(void)
+{
   if (pimpl->animation_manager_) {
     pimpl->animation_manager_->evaluate();
   }
@@ -640,7 +648,7 @@ void ThemeClockDraw::evaluateAnimation(void) {
 
 
 // 表示セルの更新
-void ThemeClockDraw::updateCell(int index) {
-
+void ThemeClockDraw::updateCell(int index)
+{
   redraw(pimpl->sec_offset_, pimpl->parent_widget_, index);
 }
