@@ -7,9 +7,10 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ThemeResource.h 263 2009-01-30 14:48:10Z satofumi $
 */
 
+#include <QPoint>
 #include <QMap>
 #include <string>
 
@@ -20,7 +21,8 @@ class QRect;
 /*!
   \brief テーマ時計のリソース
 */
-class ThemeResource {
+class ThemeResource
+{
 public:
   QMap<std::string, QPixmap*> pixmap; //!< 画像
   QMap<std::string, QRect> offset;    //!< 位置
@@ -31,8 +33,8 @@ public:
 /*!
   \brief デジタル位置の設定を読み出し
 
-  \param digital_positions [i] デジタル文字位置
-  \param tags [i] 配置情報リソース
+  \param[in] digital_positions デジタル文字位置
+  \param[in] tags 配置情報リソース
 */
 extern void loadDigitalPosition(QVector<QPoint>& digital_positions,
                                 const QMap<std::string, std::string>& tags);
