@@ -1,52 +1,62 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ja_JP">
+<!DOCTYPE TS>
+<TS version="2.0" language="ja_JP">
 <context>
     <name>@default</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="184"/>
         <source>Ctrl+Q</source>
-        <translation>Ctrl+Q</translation>
+        <translation type="obsolete">Ctrl+Q</translation>
     </message>
 </context>
 <context>
     <name>ClockSettingDialog</name>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="18"/>
+        <location filename="ClockSettingDialogForm.ui" line="19"/>
         <source>qtmclock: Setting</source>
         <translation>テーマ時計: 設定</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="107"/>
+        <location filename="ClockSettingDialogForm.ui" line="93"/>
+        <source>Placement</source>
+        <translation>配置</translation>
+    </message>
+    <message>
+        <location filename="ClockSettingDialogForm.ui" line="99"/>
+        <source>Places the window at the top of the Z order.</source>
+        <translation>常に最も手前に表示する。</translation>
+    </message>
+    <message>
+        <location filename="ClockSettingDialogForm.ui" line="124"/>
         <source>&amp;Close</source>
         <translation>閉じる (&amp;C)</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="32"/>
+        <location filename="ClockSettingDialogForm.ui" line="33"/>
         <source>Scale</source>
         <translation>拡大率</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="24"/>
+        <location filename="ClockSettingDialogForm.ui" line="25"/>
         <source>View Config</source>
         <translation>外観設定</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="52"/>
+        <location filename="ClockSettingDialogForm.ui" line="53"/>
         <source>change view scale.</source>
         <translation>表示の拡大率を変更します.</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="42"/>
+        <location filename="ClockSettingDialogForm.ui" line="43"/>
         <source>100 %</source>
         <translation>100 %</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialog.cpp" line="50"/>
+        <location filename="ClockSettingDialog.cpp" line="58"/>
         <source>%1 %</source>
         <translation>%1 %</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="82"/>
+        <location filename="ClockSettingDialogForm.ui" line="83"/>
         <source>no animation.</source>
         <translation>アニメーションなし.</translation>
     </message>
@@ -54,12 +64,12 @@
 <context>
     <name>QAction</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="183"/>
+        <location filename="ThemeClockWidget.cpp" line="198"/>
         <source>E&amp;xit</source>
         <translation>終了(&amp;x)</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="178"/>
+        <location filename="ThemeClockWidget.cpp" line="193"/>
         <source>Config</source>
         <translation>設定</translation>
     </message>
@@ -67,7 +77,7 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="ThemeClockDraw.cpp" line="77"/>
+        <location filename="ThemeClockDraw.cpp" line="81"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
     </message>
@@ -75,12 +85,17 @@
 <context>
     <name>ThemeClockWidget</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="295"/>
+        <location filename="ThemeClockWidget.cpp" line="199"/>
+        <source>Ctrl+Q</source>
+        <translation>Ctrl+Q</translation>
+    </message>
+    <message>
+        <location filename="ThemeClockWidget.cpp" line="313"/>
         <source>qtmclock</source>
         <translation>qtmclock</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="296"/>
+        <location filename="ThemeClockWidget.cpp" line="314"/>
         <source>%1 is not correct theme file.</source>
         <translation>%1 はテーマファイルではありません.</translation>
     </message>
