@@ -4,24 +4,25 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: CellPreviewWidget.cpp 261 2009-01-22 06:48:10Z satofumi $
 */
 
 #include "CellPreviewWidget.h"
 
 
-struct CellPreviewWidget::pImpl {
-
+struct CellPreviewWidget::pImpl
+{
   // !!!
 };
 
 
 CellPreviewWidget::CellPreviewWidget(QWidget* parent)
-  : QWidget(parent), pimpl(new pImpl) {
-
+  : QWidget(parent), pimpl(new pImpl)
+{
   // !!!
 }
 
 
-CellPreviewWidget::~CellPreviewWidget(void) {
+CellPreviewWidget::~CellPreviewWidget(void)
+{
 }
