@@ -7,7 +7,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: PartsPlaceScene.h 261 2009-01-22 06:48:10Z satofumi $
 */
 
 #include <QGraphicsScene>
@@ -16,28 +16,26 @@
 /*!
   \brief 部品配置の閲覧シーンクラス
 */
-class PartsPlaceScene : public QGraphicsScene {
+class PartsPlaceScene : public QGraphicsScene
+{
   Q_OBJECT;
 
   PartsPlaceScene(const PartsPlaceScene& rhs);
   PartsPlaceScene& operator = (const PartsPlaceScene& rhs);
 
-  struct pImpl;
-  std::auto_ptr<pImpl> pimpl;
-
 protected:
   /*!
-	\brief イベント制御
+    \brief イベント制御
 
-	\param mouseEvent [i/o] イベント
+    \param[in,out] mouseEvent イベント
   */
   void mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent);
 
 public:
   /*!
-	\brief コンストラクタ
+    \brief コンストラクタ
 
-	\param parent [i] 親ウィジット
+    \param[in] parent 親ウィジット
   */
   PartsPlaceScene(QObject* parent = 0);
   ~PartsPlaceScene(void);
@@ -46,8 +44,8 @@ signals:
   /*!
     \brief クリック位置の送信シグナル
 
-    \param x [i] ウィジット内クリック X 値
-    \param y [i] ウィジット内クリック Y 値
+    \param[in] x ウィジット内クリック X 値
+    \param[in] y ウィジット内クリック Y 値
   */
   void clicked(int x, int y);
 };
